Enum ErrorKind

enum ErrorKind

A list specifying general categories of I/O error.

This list is intended to grow over time and it is not recommended to exhaustively match against it.

The documentation for this enum is taken from the std::io::ErrorKind.

Variants

Interrupted

This operation was interrupted.

Interrupted operations can typically be retried.

WriteZero

An error returned when an operation could not be completed because a call to write returned Ok(0).

This typically means that an operation could only succeed if it wrote a particular number of bytes but only a smaller number of bytes could be written.

Other

An error that does not fall under any other I/O error kind.

Implementations

impl Clone for ErrorKind

fn clone(self: &Self) -> ErrorKind

impl Copy for ErrorKind

impl Debug for ErrorKind

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for ErrorKind

impl Freeze for ErrorKind

impl PartialEq for ErrorKind

fn eq(self: &Self, other: &ErrorKind) -> bool

impl RefUnwindSafe for ErrorKind

impl Send for ErrorKind

impl StructuralPartialEq for ErrorKind

impl Sync for ErrorKind

impl Unpin for ErrorKind

impl UnsafeUnpin for ErrorKind

impl UnwindSafe for ErrorKind

impl<T> Any for ErrorKind

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ErrorKind

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ErrorKind

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for ErrorKind

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for ErrorKind

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for ErrorKind

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for ErrorKind

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ErrorKind

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ErrorKind

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>