Enum Format

enum Format

The output file format to use to store data compressed with Zopfli.

Variants

Gzip

The gzip file format, as defined in RFC 1952.

This file format can be easily decompressed with the gzip program.

Zlib

The zlib file format, as defined in RFC 1950.

The zlib format has less header overhead than gzip, but it stores less metadata.

Deflate

The raw DEFLATE stream format, as defined in RFC 1951.

Raw DEFLATE streams are not meant to be stored as-is because they lack error detection and correction metadata. They are usually embedded in other file formats, such as gzip and zlib.

Implementations

impl Clone for Format

fn clone(self: &Self) -> Format

impl Copy for Format

impl Debug for Format

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for Format

impl RefUnwindSafe for Format

impl Send for Format

impl Sync for Format

impl Unpin for Format

impl UnsafeUnpin for Format

impl UnwindSafe for Format

impl<T> Any for Format

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Format

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Format

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Format

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Format

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Format

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Format

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Format

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Format

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>