Struct Options
struct Options { ... }
Options for the Zopfli compression algorithm.
Fields
iteration_count: NonZeroU64Maximum amount of times to rerun forward and backward pass to optimize LZ77 compression cost. Good values: 10, 15 for small files, 5 for files over several MB in size or it will be too slow.
Default value: 15.
iterations_without_improvement: NonZeroU64Stop after rerunning forward and backward pass this many times without finding a smaller representation of the block.
Default value: practically infinite (maximum
u64value)maximum_block_splits: u16Maximum amount of blocks to split into (0 for unlimited, but this can give extreme results that hurt compression on some files).
Default value: 15.
Implementations
impl Clone for Options
fn clone(self: &Self) -> Options
impl Copy for Options
impl Debug for Options
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for Options
fn default() -> Self
impl Eq for Options
impl Freeze for Options
impl Hash for Options
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for Options
fn cmp(self: &Self, other: &Options) -> Ordering
impl PartialEq for Options
fn eq(self: &Self, other: &Options) -> bool
impl PartialOrd for Options
fn partial_cmp(self: &Self, other: &Options) -> Option<Ordering>
impl RefUnwindSafe for Options
impl Send for Options
impl StructuralPartialEq for Options
impl Sync for Options
impl Unpin for Options
impl UnsafeUnpin for Options
impl UnwindSafe for Options
impl<T> Any for Options
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Options
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Options
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Options
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Options
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Options
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Options
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Options
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Options
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>